# CallLuaFunction()
CallLuaFunction —— C#调用lua函数
## 注意事项
GetFunction() —— 该函数：获取lua中指定test类的luaFunc函数  
***注意： 只有先添加了AddSearchPath()搜索路径，才可以保证以下2个函数的正常调用***  
DoFile() —— 该函数:执行 ScriptsFromFile.lua 脚本  
Require() —— 该函数：执行 引用 ScriptsFromFile lua 脚本  
## 代码示例
```Csharp
using UnityEngine;
using LuaInterface;
using System;
/// <summary>
/// Chinar解释 —— tolua官方测试案例 3
/// C#调用lua函数
/// </summary>
public class CallLuaFunction : MonoBehaviour
{
    private string script =
        @"  function luaFunc(num)                        
                return num + 1
            end
            test = {}
            test.luaFunc = luaFunc
			function ChinarTest()
                print('通过lua对象获取函数')
            end
        ";
    LuaFunction luaFunc = null;
    LuaState    lua     = null;
    string      tips    = null;
    void Start()
    {
#if UNITY_5 || UNITY_2017 || UNITY_2018
        Application.logMessageReceived += ShowTips;
#else
        Application.RegisterLogCallback(ShowTips);
#endif
        new LuaResLoader();
        lua = new LuaState();
        lua.Start();
        DelegateFactory.Init();
        lua.DoString(script);
        luaFunc = lua.GetFunction("test.luaFunc"); //获取test中的luaFunc函数

        if (luaFunc != null)
        {
            //第一种方法 —— luaFunc.Invoke
            int num = luaFunc.Invoke<int, int>(123456);    //调用函数返回int值
            Debugger.Log("generic call return: {0}", num); //123457

            //第二种方法
            luaFunc.BeginPCall();
            luaFunc.Push(123456);
            luaFunc.PCall();
            num = (int) luaFunc.CheckNumber();
            luaFunc.EndPCall();
            Debugger.Log("expansion call return: {0}", num); //123457

            //第三种方法 —— 委托调用
            Func<int, int> Func = luaFunc.ToDelegate<Func<int, int>>();
            num = Func(123456);
            Debugger.Log("Delegate call return: {0}", num); //123457

            //第四种方法 —— lua.Invoke
            num = lua.Invoke<int, int>("test.luaFunc", 123456, true);
            Debugger.Log("luastate call return: {0}", num); //123457

			      //第五种方法 —— LuaFunction . Call()
            LuaFunction func = lua["ChinarTest"] as LuaFunction; //lua对象 转 lua函数
            func.Call();                                       //调用lua TestFunc 函数
            func.Dispose();
        }
        lua.CheckTop();
    }


    void ShowTips(string msg, string stackTrace, LogType type)
    {
        tips += msg;
        tips += "\r\n";
    }


#if !TEST_GC
    void OnGUI()
    {
        GUI.Label(new Rect(Screen.width / 2 - 200, Screen.height / 2 - 150, 400, 300), tips);
    }
#endif


    void OnDestroy()
    {
        if (luaFunc != null)
        {
            luaFunc.Dispose();
            luaFunc = null;
        }

        lua.Dispose();
        lua = null;

#if UNITY_5 || UNITY_2017 || UNITY_2018
        Application.logMessageReceived -= ShowTips;
#else
        Application.RegisterLogCallback(null);
#endif
    }
}

```
