# AccessingLuaVariables()
C#访问lua变量
## 注意事项
***注意： lua["变量名"] —— 通过这种方式对 lua 中的变量进行访问***  
lua["TestFunc"] as LuaFunction ——	LuaState 对象 转 LuaFunction，调用 lua 中 TestFunc 函数  
lua.GetTable("lua 中的表名") —— 获取 lua 中的表，返回类型为LuaTable  
## 代码示例
```Csharp
using UnityEngine;
using LuaInterface;
/// <summary>
/// Chinar解释 —— tolua官方测试案例 4
/// C#访问lua中的变量
/// </summary>
public class AccessingLuaVariables : MonoBehaviour
{
    private string script =
        @"
            print('Objs2Spawn is: '..Objs2Spawn)
            var2read = 42
            varTable = {1,2,3,4,5}
            varTable.default = 1
            varTable.map = {}
            varTable.map.name = 'map'
            print(varTable.map.name)
            meta = {name = 'meta'}
            setmetatable(varTable, meta)

            function TestFunc(strs)
                print('get func by variable')
            end
        "; //lua脚本

    void Start()
    {
#if UNITY_5 || UNITY_2017 || UNITY_2018
        Application.logMessageReceived += ShowTips;
#else
        Application.RegisterLogCallback(ShowTips);
#endif
        new LuaResLoader();
        LuaState lua = new LuaState();
        lua.Start();
        lua["Objs2Spawn"] = 5; //对lua脚本中 Objs2Spawn 赋值 5
        lua.DoString(script);

        //通过LuaState访问 —— 从lua中读取 var2read 的值
        Debugger.Log("Read var from lua: {0}", lua["var2read"]); //42

        //LuaState 拆串式table，读取lua表中的值
        Debugger.Log("Read table var from lua: {0}", lua["varTable.default"]); //1

        LuaFunction func = lua["TestFunc"] as LuaFunction; //lua对象 转 lua函数
        func.Call();                                       //调用lua TestFunc 函数
        func.Dispose();

        //cache成LuaTable进行访问
        LuaTable table = lua.GetTable("varTable");
        Debugger.Log("Read varTable from lua, default: {0} name: {1}", table["default"], table["map.name"]);//1 和 无
        table["map.name"] = "new";                                    //table 字符串只能是key
        Debugger.Log("Modify varTable name: {0}", table["map.name"]); //打印 new

        table.AddTable("newmap"); //表中添加 newmap                   
        //这里 table["newmap"] 是Object类型，所以需要强转为 LuaTable类型
        LuaTable table1 = (LuaTable) table["newmap"];
        table1["name"]  = "table1";
        Debugger.Log("varTable.newmap name: {0}", table1["name"]); //打印table1
        table1.Dispose();

        table1 = table.GetMetaTable(); //获取元表，并赋值
        if (table1 != null)
        {
            Debugger.Log("varTable metatable name: {0}", table1["name"]);
        }

        object[] list = table.ToArray();

        for (int i = 0; i < list.Length; i++)
        {
            Debugger.Log("varTable[{0}], is {1}", i, list[i]);
        }

        table.Dispose(); //释放表
        lua.CheckTop();  //检验
        lua.Dispose();   //释放
    }


    private void OnApplicationQuit()
    {
#if UNITY_5 || UNITY_2017 || UNITY_2018
        Application.logMessageReceived -= ShowTips;
#else
        Application.RegisterLogCallback(null);
#endif
    }


    string tips = null;


    void ShowTips(string msg, string stackTrace, LogType type)
    {
        tips += msg;
        tips += "\r\n";
    }


    void OnGUI()
    {
        GUI.Label(new Rect(Screen.width / 2 - 300, Screen.height / 2 - 200, 600, 400), tips);
    }
}
```
